
//------------------------------------------------------------------------
//------------------------------ the Axis --------------------------------
//------------------------------------------------------------------------
#macro Axis_(AxisLen, Dark_Texture, Light_Texture) 
union {
  cylinder {
    <0, -AxisLen, 0>, <0, AxisLen, 0>, 0.05
    texture {
      checker
      texture {Dark_Texture} 
      texture {Light_Texture}
      translate <0.1, 0, 0.1>
    }
  }
  cone {
    <0, AxisLen, 0>, 0.2, <0, AxisLen+0.7, 0>, 0
    texture {Dark_Texture}
  }
}                  
#end // of macro "Axis_()"

//--------------------- drawing of 3 Axes --------------------------------
#macro AxisXYZ(AxisLenX, AxisLenY, AxisLenZ, Tex_Dark, Tex_Light)
union {
  #if (AxisLenX != 0)
    object {Axis_(AxisLenX, Tex_Dark, Tex_Light) rotate <0, 0, -90>}  //x-Axis
    text {
      ttf "arial.ttf", "x", 0.15, 0 texture {Tex_Dark} 
      rotate <0, 0, 0>
      scale 0.65
      translate <AxisLenX+0.05, 0.4, -0.10>
    }
  #end // of #if 
  
  #if (AxisLenY != 0)
    object {Axis_(AxisLenY, Tex_Dark, Tex_Light) rotate <0, 0, 0>}  //y-Axis
    text {
      ttf "arial.ttf", "y", 0.15, 0 texture {Tex_Dark}    
      rotate <0, 0, 0>
      scale 0.65
      translate <-0.65, AxisLenY+0.20, -0.10>
      rotate <0, 0, 0>
    }
  #end // of #if
  
  #if (AxisLenZ != 0)
    object {Axis_(AxisLenZ, Tex_Dark, Tex_Light) rotate <90, 0, 0>}  //z-Axis
    text {
      ttf "arial.ttf", "z", 0.15, 0 texture {Tex_Dark}
      rotate <0, 0, 0>
      scale 0.65
      translate <-0.75, 0.2, AxisLenZ+0.10>
    }
  #end // of #if 
  scale 20
} // end of union                      
#end// of macro "AxisXYZ( ... )"

//--------------------- textures of 3 Axes -------------------------------
#declare Texture_A_Dark=
texture {
  pigment {color srgb <0.7, 0.0, 0.0>}
  finish {diffuse 0.8}
}
#declare Texture_A_Light=
texture { 
  pigment {color srgb <0.9, 0.9, 0.9>}
  finish {diffuse 0.8}
}

//--------------------- invoking the macro -------------------------------
#macro MyAxis(Xlength, Ylength, Zlength, Scale)
object {AxisXYZ(Xlength, Ylength, Zlength, Texture_A_Dark, Texture_A_Light) scale Scale /*no_shadow*/}
#end

//-------------------------------------------------- end of coordinate axes

